# Sonolus.py
Sonolus.py is a Python library for creating Sonolus engines.

## Installation
Sonolus.py is available on PyPI and can be installed using a package manager like pip.

=== "pip"
    ```bash
    pip install sonolus.py
    ```
=== "uv"
    ```bash
    uv add sonolus.py
    ```

## Getting Started
Example Projects:

- [pydori](https://github.com/qwewqa/pydori): A Bandori-like engine designed to be an example project for Sonolus.py.

New Project Template: [sonolus.py-template-project](https://github.com/qwewqa/sonolus.py-template-project)

## Documentation

- [Overview](overview.md): High-level overview of Sonolus.py.
- [Concepts](concepts/index.md): Detailed information on concepts and usage.
- [Reference](reference/index.md): Detailed information on included classes and functions.
